﻿using UnityEngine;
using UnityEngine.SceneManagement;

//todo fix lighting pad

public class Rocket : MonoBehaviour
{
    [SerializeField]  float rcsThrust = 100f;
    [SerializeField] float mainThrust = 100f;

    [SerializeField] AudioClip Engine;
    [SerializeField] AudioClip SuccessSound;
    [SerializeField] AudioClip DeathSound;

    [SerializeField] ParticleSystem mainEnginerParticle;    //Particle systems
    [SerializeField] ParticleSystem successParticle;
    [SerializeField] ParticleSystem deathParticle;

    Rigidbody rigidbody;
    AudioSource audioSource;

    enum State { Alive, Dying, Transcending }
    State state = State.Alive;
    // Use this for initialization
    void Start()
    {
        rigidbody = GetComponent<Rigidbody>();
        audioSource = GetComponent<AudioSource>();

    }

    // Update is called once per frame
    void Update()
        //todo stop sound on death
    {
        if (state == State.Alive)
        {
            print("Update");
            RespondtoThrustInput();
            RespondtoRotateInput();
            
        }
        
    }

    void OnCollisionEnter(Collision collision)
    {
        if (state != State.Alive)
        {
            return; 
        }
        print("collision");

        switch(collision.gameObject.tag)
        {
            case "Friendly":
                //do nothing
                print("Sucessful Landing");
                break;
            case "End":
                SuccessSequence();
                break;
            default:
                DeathSequence();
                break;
        }
    }

    private void SuccessSequence()
    {
        state = State.Transcending;
        audioSource.Stop();
        audioSource.PlayOneShot(SuccessSound);
        successParticle.Play();
        Invoke("LoadNextScene", 1f); //parameterize this time
    }

    private void DeathSequence()
    {
        state = State.Dying;               
        audioSource.Stop();
        print("death Sound");
        audioSource.PlayOneShot(DeathSound);
        deathParticle.Play();
        Invoke("LoadFirstLevel", 1f);
    }

    private void LoadFirstLevel()
    {
        SceneManager.LoadScene(0);
    }

    private void LoadNextScene() //todo allow for more levels
    {
        SceneManager.LoadScene(1);
    }

    private void RespondtoThrustInput()
    {
        if (Input.GetKey(KeyCode.Space))    // Can thrust while rotating
        {
            ApplyThrusting();
            

        }
        else
        {
            audioSource.Stop();
            mainEnginerParticle.Stop(); 
            print("No sound");
        }
    }

    private void ApplyThrusting()
    {
        //print("Thrust");
        rigidbody.AddRelativeForce(Vector3.up * mainThrust);
        if (!audioSource.isPlaying) // so it doesnt layer
        {
            audioSource.PlayOneShot(Engine);
            print("playing sound");

        }
        mainEnginerParticle.Play();
    }

    private void RespondtoRotateInput()
    {
        rigidbody.freezeRotation = true;
        float rotationThisFrame = rcsThrust * Time.deltaTime;

        if (Input.GetKey(KeyCode.A))
        {
            
            print("Rotating left");
            transform.Rotate(Vector3.forward * rotationThisFrame);
        }
        else if (Input.GetKey(KeyCode.D))
        {
            
            print("Rotating right");
           
            transform.Rotate(-Vector3.forward * rotationThisFrame);
            
        }
        rigidbody.freezeRotation = false;
    }

   
}
